<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>QApplication</name>
    <message>
        <source>MX Tweak</source>
        <translation type="obsolete">MX Tweak</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="obsolete">Dieses Programm funktioniert nur mit Xfce</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Hauptfenster</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software (xrandr) Helligkeit</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Hardware-Hintergrundbeleuchtung</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="30"/>
        <source>MX-Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="56"/>
        <source>Display</source>
        <translation>Bildschirm</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="61"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="52"/>
        <location filename="../defaultlook.cpp" line="67"/>
        <location filename="../defaultlook.cpp" line="586"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <location filename="../defaultlook.cpp" line="610"/>
        <location filename="../defaultlook.cpp" line="621"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="147"/>
        <source>Xfce Settings</source>
        <translation>Xfce-Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Leiste anpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="48"/>
        <location filename="../defaultlook.ui" line="161"/>
        <source>Panel</source>
        <translation>Leiste</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="68"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Fensterverhalten und Tastenkürzel anpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="82"/>
        <source>Window Manager</source>
        <translation>Fensterverwaltung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="102"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Aussehen Ihres Desktops anpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="116"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1673"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1684"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1701"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1704"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1711"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="169"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="189"/>
        <source>Backup current panel configuration</source>
        <translation>Aktuelle Leistenkonfiguration sichern</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="196"/>
        <source>Restore backup panel configuration</source>
        <translation>Gesicherte Leistenkonfiguration wiederhestellen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="203"/>
        <source>Restore default panel</source>
        <translation>Standardleiste wiederherstellen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="216"/>
        <location filename="../defaultlook.ui" line="1416"/>
        <source>Affects 1st panel</source>
        <translation>Betrifft 1. Leiste</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Display panel vertically</source>
        <translation>Leiste senkrecht anzeigen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <location filename="../defaultlook.ui" line="1329"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="248"/>
        <location filename="../defaultlook.ui" line="1339"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="256"/>
        <source>Display panel horizontally</source>
        <translation>Leiste waagerecht anzeigen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="276"/>
        <location filename="../defaultlook.ui" line="1334"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="281"/>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="289"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;wirksam für ALLE Leisten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="309"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Fensterknöpfe&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="324"/>
        <location filename="../defaultlook.ui" line="427"/>
        <location filename="../defaultlook.ui" line="618"/>
        <location filename="../defaultlook.ui" line="748"/>
        <location filename="../defaultlook.ui" line="871"/>
        <location filename="../defaultlook.ui" line="878"/>
        <location filename="../defaultlook.ui" line="971"/>
        <location filename="../defaultlook.ui" line="1287"/>
        <location filename="../defaultlook.ui" line="1365"/>
        <location filename="../defaultlook.ui" line="1600"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="361"/>
        <source>Theme Options</source>
        <translation>Themenoptionen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="391"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Einige Webseiten-Felder für das Farbschema &quot;dunkel&quot; korrigieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="394"/>
        <source>Firefox dark theme tweak</source>
        <translation>Dunkel angepasstes Firefox-Farbschema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="401"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>HexChat Eingabefeld in dunklem Thema reparieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="453"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="460"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="467"/>
        <source>Remove User Theme Set</source>
        <translation>Theme Set entfernen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="478"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Einstellungen als Theme Set speichern</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Starte compton-conf Konfigurationswerkzeug</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Compton settings</source>
        <translation>Compton-Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="540"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Einstellungen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="543"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm-Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="567"/>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="572"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="577"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="585"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Bearbeite compton.conf direkt im Texteditor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Edit compton.conf</source>
        <translation>Bearbeite compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="645"/>
        <source>Transparency and shadow options</source>
        <translation>Transparenz- und Schattenoptionen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="652"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Eine Änderung des VBlank Modus kann eventuell einige unangenehme Bildschirmprobleme lindern.  Unter der Hilfe gibt es mehr Informationen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="655"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="663"/>
        <source>auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="668"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="673"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="678"/>
        <source>off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="888"/>
        <source>Config Options</source>
        <translation>Konfigurationsoptionen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1423"/>
        <source>Systray Icon Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1434"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1439"/>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1444"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1449"/>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1454"/>
        <source>Larger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1459"/>
        <source>Largest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1478"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Lightdm (Login Bildschirm) auf die Systemvoreinstellung zurücksetzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="896"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Benutzerdefinierten Aktionen in Thunar auf die Systemvoreinstellungen zurücksetzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1501"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Intel Treiber anstelle des voreingestellten &quot;modesetting&quot; Treibers benutzen (Neustart erforderlich)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1508"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-intel.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1519"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Option &quot;Tearfree&quot; des AMDGPU-Treibers benutzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1526"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-amd.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1537"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Option &quot;Tearfree&quot; des Radeon-Treibers benutzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1544"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-radeon.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>Display</source>
        <translation>Bildschirm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Hardware Backlight</source>
        <translation>Hintergrundbeleuchtung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="714"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bildschirm Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="741"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Bildschirm für xrandr Tweaks auswählen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>Resolution</source>
        <translation>Bildschirmauflösung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="781"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Abspeicherung geschieht per Bildschirm&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="784"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software (xrandr) Helligkeit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="798"/>
        <location filename="../defaultlook.ui" line="812"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="805"/>
        <source>GTK scaling</source>
        <translation>GTK Skalierung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="832"/>
        <source>xrandr Scaling</source>
        <translation>xrandr Skalierung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="985"/>
        <source>Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1022"/>
        <location filename="../defaultlook.ui" line="1053"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1027"/>
        <location filename="../defaultlook.ui" line="1058"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1063"/>
        <source>On Hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1199"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="993"/>
        <location filename="../defaultlook.ui" line="1376"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1000"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1007"/>
        <source>Reset DefaultDock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1014"/>
        <source>Toggle desktop icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1035"/>
        <source>Reset Fluxbox Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1042"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1084"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1091"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1098"/>
        <location filename="../defaultlook.ui" line="1206"/>
        <location filename="../defaultlook.ui" line="1383"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1182"/>
        <location filename="../defaultlook.ui" line="1280"/>
        <source>Autohide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1189"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>Plasma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1352"/>
        <source>Enable single-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1318"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1470"/>
        <source>Other</source>
        <translation>Sonstiges</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1567"/>
        <source>&amp;User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1574"/>
        <source>Root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="917"/>
        <source>Show systray (notification area) frame</source>
        <translation>Zeige Rahmen um das Benachrichtigungsfeld (Systray)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="924"/>
        <location filename="../defaultlook.ui" line="1403"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Zeige Fenster von allen Arbeitsflächen in der Leiste</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="903"/>
        <source>Enable single-click on desktop</source>
        <translation>Einfach-Klick auf dem Desktop aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="938"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Ruhezustand im Log-Out Menü zulassen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Aktiviere Einhängen von internen Laufwerken durch Benutzer ohne root-Rechte</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1492"/>
        <source>Enable kernel sandbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="945"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>Hinweis: Für den Ruhezustand wird SWAP &gt;= RAM benötigt.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="931"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Verkürzung langer Dateinamen auf dem Desktop abschalten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="910"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Einfach-Klick im Thunar Dateimanager aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1560"/>
        <source>Password for administrative tasks:</source>
        <translation>Passwort für administrative Aufgaben:</translation>
    </message>
    <message>
        <source>User</source>
        <translation type="vanished">Benutzer</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="53"/>
        <source>--display switch only valid for Xfce</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="585"/>
        <source>About MX Tweak</source>
        <translation>Über MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="586"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="587"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Anwendung für schnelle Änderungen und Anpassungen an den Voreinstellungen des UI-Themas</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="589"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="590"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="591"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="622"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Fertig! Die Änderungen werden nach einem Neustart von Firefox wirksam.</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="vanished">Dieses Programm funktioniert nur mit Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="806"/>
        <source>Panel settings</source>
        <translation>Leisten-Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="807"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Die aktuellen Panel-Einstellungen wurden im versteckten Ordner .restore im Home-Ordner gesichert (~/.restore/).</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1408"/>
        <source>settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1745"/>
        <source>Choose a theme set</source>
        <translation>Wählen Sie ein Thema</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Theme Set entfernen</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Neues Theme Set</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Namen für das neue Theme Set eingeben</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Fensterknöpfe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aussehen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Knopfbeschriftungen anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Flache Knöpfe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Griff anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Sortierreihenfolge:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Zeitstempel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Titel und Zeitstempel gruppieren</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Fenstertitel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Titel und Fenstertitel gruppieren</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Keine, ziehen und ablegen ermöglichen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Verhalten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Fenstergruppierung:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Immer</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Mittelklickaktion:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Fenster schließen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Fenster verkleinern</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Verkleinerte Fenster in aktueller Arbeitsfläche wiederherstellen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Fensterrahmen zeichnen, wenn ein Knopf mit der Maus überfahren wird</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Fenster mit dem Mausrad wechseln</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtern&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Fenster aller Arbeitsflächen oder Anzeigenbereiche anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Nur verkleinerte Fenster anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Fenster von allen Bildschirmen anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Popup-Fenster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Fenster während des Verschiebens</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Deckkraft-Einstellungen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Fensterrahmen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Zeige Schatten unter Dockfenstern</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Zeige Schatten unter Popup-Fenstern</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Fenster während der Größenänderung</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Zeige Schatten unter gewöhnlichen Fenstern</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Funktionseinstellungen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Zeige beim Durchlauf Fenstervorschauen anstatt Symbole</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Vollbildüberlagerungsfenster sofort anzeigen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Inaktive Fenster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Zeichnen mit der vertikalen Austastlücke synchronisieren</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor Einstellungen</translation>
    </message>
</context>
</TS>
